==> apache-cassandra-analytics-0.2.0-src.tar.gz: apache-cassandra-analytics-0.2.0-src/cassandra-analytics-spark-converter/src/main/scala-2.12-spark-2/org/apache/cassandra/spark/utils/ScalaConversionUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cassandra.spark.utils;

import java.util.List;

import scala.collection.JavaConverters;
import scala.collection.mutable.Seq;

/**
 * Compatibility layer for scala conversions
 */
public final class ScalaConversionUtils
{
    private ScalaConversionUtils()
    {
        throw new IllegalStateException(getClass() + " is static utility class and shall not be instantiated");
    }

    public static <A> java.lang.Iterable<A> asJavaIterable(scala.collection.Iterable<A> iterable)
    {
        return JavaConverters.asJavaIterable(iterable);
    }

    public static <A> scala.collection.Iterator<A> asScalaIterator(java.util.Iterator<A> iterator)
    {
        return JavaConverters.asScalaIterator(iterator);
    }

    public static <A, B> java.util.Map<A, B> mapAsJavaMap(scala.collection.Map<A, B> map)
    {
        return JavaConverters.mapAsJavaMap(map);
    }

    public static <A> List<A> mutableSeqAsJavaList(Seq<A> seq)
    {
        return JavaConverters.mutableSeqAsJavaList(seq);
    }
}

==> apache-cassandra-analytics-0.3.0-src.tar.gz: apache-cassandra-analytics-0.3.0-src/cassandra-analytics-spark-converter/src/main/scala-2.11-spark-2/org/apache/cassandra/spark/utils/ScalaConversionUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cassandra.spark.utils;

import java.util.List;

import scala.collection.JavaConversions;
import scala.collection.mutable.Seq;

/**
 * Compatibility layer for scala conversions
 */
public final class ScalaConversionUtils
{
    private ScalaConversionUtils()
    {
        throw new IllegalStateException(getClass() + " is static utility class and shall not be instantiated");
    }

    public static <A> java.lang.Iterable<A> asJavaIterable(scala.collection.Iterable<A> iterable)
    {
        return JavaConversions.asJavaIterable(iterable);
    }

    public static <A> scala.collection.Iterator<A> asScalaIterator(java.util.Iterator<A> iterator)
    {
        return JavaConversions.asScalaIterator(iterator);
    }

    public static <A, B> java.util.Map<A, B> mapAsJavaMap(scala.collection.Map<A, B> map)
    {
        return JavaConversions.mapAsJavaMap(map);
    }

    public static <A> List<A> mutableSeqAsJavaList(Seq<A> seq)
    {
        return JavaConversions.mutableSeqAsJavaList(seq);
    }
}
